Index: wp-includes/kses.php
===================================================================
--- wp-includes/kses.php	(revision 40723)
+++ wp-includes/kses.php	(working copy)
@@ -629,11 +629,11 @@
 		 *
 		 * @since 3.5.0
 		 *
 		 * @param string $tags    Allowed tags, attributes, and/or entities.
 		 * @param string $context Context to judge allowed tags by. Allowed values are 'post',
 		 *                        'data', 'strip', 'entities', 'explicit', or the name of a filter.
 		 */
-		return apply_filters( 'wp_kses_allowed_html', $context, 'explicit' );
+		return apply_filters( 'wp_kses_allowed_html', $allowedtags, 'explicit' );
 	}
 
 	switch ( $context ) {
@@ -629,11 +629,11 @@
 		 * @since 3.5.0
 		 *
-		 * @param string $tags    Allowed tags, attributes, and/or entities.
-		 * @param string $context Context to judge allowed tags by. Allowed values are 'post',
-		 *                        'data', 'strip', 'entities', 'explicit', or the name of a filter.
+		 * @param string $allowedtags Allowed tags, attributes, and/or entities.
+		 * @param string $context     Context to judge allowed tags by. Allowed values are 'post',
+		 *                            'data', 'strip', 'entities', 'explicit', or the name of a filter.
 		 */
